@@ -23,6 +23,7 @@
  */
 
 #include <bluetooth/bluetooth.h>
+#include <dbus/dbus.h>
 #include <glib.h>
 
 #define ADAPTER_INTERFACE	"org.bluez.Adapter"
@@ -68,7 +69,6 @@ struct hci_dev {
 
 	uint8_t  ssp_mode;
 	uint8_t  name[MAX_NAME_LENGTH];
-	uint8_t  class[3];
 };
 
 int adapter_start(struct btd_adapter *adapter);
@@ -77,10 +77,6 @@ int adapter_stop(struct btd_adapter *adapter);
 
 int adapter_update(struct btd_adapter *adapter, uint8_t cls);
 
-int adapter_get_class(struct btd_adapter *adapter, uint8_t *cls);
-
-int adapter_set_class(struct btd_adapter *adapter, uint8_t *cls);
-
 int adapter_update_ssp_mode(struct btd_adapter *adapter, uint8_t mode);
 
 struct btd_device *adapter_get_device(DBusConnection *conn,
@@ -123,6 +119,7 @@ void adapter_update_oor_devices(struct btd_adapter *adapter);
 void adapter_mode_changed(struct btd_adapter *adapter, uint8_t scan_mode);
 void adapter_setname_complete(bdaddr_t *local, uint8_t status);
 void adapter_update_local_name(bdaddr_t *bdaddr, uint8_t status, void *ptr);
+void adapter_set_class_complete(bdaddr_t *bdaddr, uint8_t status);
 
 struct agent *adapter_get_agent(struct btd_adapter *adapter);
 void adapter_add_connection(struct btd_adapter *adapter,
@@ -133,8 +130,9 @@ gboolean adapter_has_discov_sessions(struct btd_adapter *adapter);
 
 struct btd_adapter *btd_adapter_ref(struct btd_adapter *adapter);
 void btd_adapter_unref(struct btd_adapter *adapter);
-int set_major_and_minor_class(struct btd_adapter *adapter, uint8_t major,
-								uint8_t minor);
+
+int btd_adapter_set_class(struct btd_adapter *adapter, uint8_t major,
+							uint8_t minor);
 
 
 struct btd_adapter_driver {
@@ -158,6 +156,8 @@ void btd_adapter_any_release_path(void);
 gboolean adapter_is_pairable(struct btd_adapter *adapter);
 gboolean adapter_powering_down(struct btd_adapter *adapter);
 
+int btd_adapter_restore_powered(struct btd_adapter *adapter);
+int btd_adapter_switch_offline(struct btd_adapter *adapter);
 
 struct btd_adapter_ops {
 	int (*setup) (void);
@@ -167,7 +167,7 @@ struct btd_adapter_ops {
 	int (*set_powered) (int index, gboolean powered);
 	int (*set_connectable) (int index);
 	int (*set_discoverable) (int index);
-	int (*set_limited_discoverable) (int index, const uint8_t *cls,
+	int (*set_limited_discoverable) (int index, uint32_t class,
 						gboolean limited);
 	int (*start_discovery) (int index, gboolean periodic);
 	int (*stop_discovery) (int index);
@@ -175,6 +175,7 @@ struct btd_adapter_ops {
 	int (*cancel_resolve_name) (int index, bdaddr_t *bdaddr);
 	int (*set_name) (int index, const char *name);
 	int (*read_name) (int index);
+	int (*set_class) (int index, uint32_t class);
 };
 
 int btd_register_adapter_ops(struct btd_adapter_ops *btd_adapter_ops);
